import { transformError as sdkTransformError } from '@wix/sdk-runtime/transform-error';
import { renameKeysFromSDKRequestToRESTRequest } from '@wix/sdk-runtime/rename-all-nested-keys';
import * as ambassadorWixAutomationsV1AutomationsCustomTrigger from './automations-v1-automations-custom-trigger-custom-trigger.http.js';
/**
 * Runs the automation associated with the trigger ID that you pass to it.
 * @public
 * @permissionId AUTOMATIONS.TRIGGER_WEBHOOK
 * @permissionScope Manage Stores
 * @permissionScopeId SCOPE.STORES.MANAGE-STORES
 * @permissionScope Access Verticals by Automations
 * @permissionScopeId SCOPE.CRM.ACCESS-VERTICALS-BY-AUTOMATIONS
 * @permissionScope Set Up Automations
 * @permissionScopeId SCOPE.CRM.SETUP-AUTOMATIONS
 * @applicableIdentity APP
 * @fqn com.wixpress.crm.automations.automations_custom_trigger.AutomationsCustomTriggerService.RunTrigger
 */
export async function runTrigger(options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        triggerId: options?.triggerId,
        payload: options?.payload,
    });
    const reqOpts = ambassadorWixAutomationsV1AutomationsCustomTrigger.runTrigger(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                triggerId: '$[0].triggerId',
                payload: '$[0].payload',
            },
            singleArgumentUnchanged: false,
        }, ['options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
//# sourceMappingURL=automations-v1-automations-custom-trigger-custom-trigger.universal.js.map